@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::Plugin::Alien::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Dist::Zilla::Plugin::Alien::VERSION = '0.009';
+  $Dist::Zilla::Plugin::Alien::VERSION = '0.010';
 }
 # ABSTRACT: Use Alien::Base with Dist::Zilla
 
@@ -189,7 +189,13 @@ around module_build_args => sub {
 					: $self->repo_uri->host_port )
 				: '',
 			location => $self->repo_uri->path,
-			pattern => qr/^$pattern$/,
+			# NOTE Not using a compiled regex here for serialisation
+			# in case it adds flags not in older versions of perl.
+			# In particular, the compiled regex was adding the u
+			# modifier, but then getting serialised as
+			# (?^u:$pattern) which fails to parse under perl less
+			# than v5.014.
+			pattern => "^$pattern\$",
 		},
 		(alien_build_commands => $self->build_command)x!! $self->build_command,
 		(alien_install_commands => $self->install_command)x!! $self->install_command,
@@ -210,7 +216,7 @@ Dist::Zilla::Plugin::Alien - Use Alien::Base with Dist::Zilla
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
